@@ -1,12 +1,13 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import Pool
-from .product import *
-from .move import *
+
+from . import move, product
 
 
 def register():
     Pool.register(
-        Template,
-        Move,
+        product.Template,
+        product.Product,
+        move.Move,
         module='product_cost_fifo', type_='model')
